from setuptools import setup, find_packages

setup(
    name="textflow_ai",
    version="0.1.1",
    packages=find_packages(),
    description="A simple AI helper library",
    author="Athira Binu",
    author_email="athirakbinu@gmail.com",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    license="MIT",
)
